camelot.camelot.view.controls.delegates.GenericDelegate

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates :: Class GenericDelegate |
[hide private]
[frames] | no frames]

# Class GenericDelegate

source code

Manages custom delegates

Instance Methods | [hide private]
__init__(self, parent=None) | source code
set_columns_desc(self, columnsdesc) | source code
insertColumnDelegate(self, column, delegate) Inserts a custom column delegate | source code
commitData(self, editor) | source code
closeEditor(self, editor) | source code
removeColumnDelegate(self, column) Removes custom column delegate | source code
paint(self, painter, option, index) Use a custom delegate paint method if it exists | source code
createEditor(self, parent, option, index) Use a custom delegate createEditor method if it exists | source code
setEditorData(self, editor, index) Use a custom delegate setEditorData method if it exists | source code
setModelData(self, editor, model, index) Use a custom delegate setModelData method if it exists | source code
sizeHint(self, option, index) | source code